![penterepTools](https://www.penterep.com/external/penterepToolsLogo.png)

# PTGETPAGE
> Get page content & headers

Script retrieves page content and HTTP headers.

## Installation

```
pip install ptgetpage
```

## Add to PATH

If you cannot invoke the script in your terminal, its probably because its not in your PATH. Fix it by running commands below.

### Add to path for BASH
```bash
echo "export PATH=\"`python3 -m site --user-base`/bin:\$PATH\"" >> ~/.bashrc
source ~/.bashrc
```
### Add to path for ZSH
```bash
echo "export PATH=\"`python3 -m site --user-base`/bin:\$PATH\"" >> ~/.zshhrc
source ~/.zshhrc
```

## Usage examples
```
ptgetpage -u https://www.example.com/
```

## Options
```
-u   --url         <url>           Connect to URL
-p   --proxy       <proxy>         Set proxy (e.g. http://127.0.0.1:8080)
-r   --redirects                   Allow redirects (default False)
-c   --cookie      <cookie>        Set cookie
-ua  --user-agent  <user-agent>    Set user agent
-H   --headers     <header:value>  Set custom headers
-j   --json                        Enable JSON output
-v   --version                     Show script version and exit
-h   --help                        Show this help message and exit
```

## Usage examples
```
$ ptgetpage -u example.com
```

## Dependencies
- requests
- ptlibs

## Version History

* 0.0.1
    * Alpha release

## Licence

Copyright (c) 2020 HACKER Consulting s.r.o.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.

## Warning

You are only allowed to run the tool against the websites which
you have been given permission to pentest. We do not accept any
responsibility for any damage/harm that this application causes to your
computer, or your network. Penterep is not responsible for any illegal
or malicious use of this code. Be Ethical!